package com.ruoyi.common.core.domain.entity;

import java.time.LocalDate;
import java.util.Date;
import java.util.List;

import javax.validation.constraints.Email;
import javax.validation.constraints.NotBlank;
import javax.validation.constraints.Size;

import com.fasterxml.jackson.annotation.JsonFormat;
import com.ruoyi.common.annotation.Excel;
import com.ruoyi.common.annotation.Excel.ColumnType;
import com.ruoyi.common.annotation.Excel.Type;
import com.ruoyi.common.annotation.Excels;
import com.ruoyi.common.core.domain.BaseEntity;
import com.ruoyi.common.core.validate.ValidGroup;
import com.ruoyi.common.xss.Xss;

import io.swagger.annotations.ApiModelProperty;
import lombok.Data;
import lombok.EqualsAndHashCode;
import lombok.NoArgsConstructor;

/**
 * 用户对象 sys_user
 *
 * @author ruoyi
 */
@Data
@EqualsAndHashCode(callSuper = true)
@NoArgsConstructor
public class SysUser extends BaseEntity
{
    private static final long serialVersionUID = 1L;

    /** 用户ID */
    @Excel(name = "ID", type = Type.EXPORT, cellType = ColumnType.NUMERIC, prompt = "用户编号")
    private Long userId;

    @Excel(name = "工号")
    @ApiModelProperty("工号")
    private String userNo;

    /** 部门ID */
    private Long deptId;

    /** 登录账号 */
    @Excel(name = "登录账号")
    @NotBlank(message = "登录账号不允许为空", groups = {ValidGroup.Create.class})
    @Xss(message = "登录账号不能包含脚本字符")
    @Size(min = 0, max = 30, message = "登录账号长度不能超过30个字符")
    private String userName;

    /** 姓名 */
    @Excel(name = "姓名")
    @Xss(message = "姓名不能包含脚本字符")
    @Size(min = 0, max = 30, message = "姓名长度不能超过30个字符")
    private String nickName;

    /** 用户邮箱 */
    @Email(message = "邮箱格式不正确")
    @Size( max = 50, message = "邮箱长度不能超过50个字符")
    private String email;

    /** 手机号码 */
    @Size(max = 11, message = "手机号码长度不能超过11个字符")
    private String phonenumber;

    /** 用户性别 */
    @Excel(name = "用户性别", readConverterExp = "0=男,1=女,2=未知", combo = {"男", "女", "未知"})
    private String sex;

    /** 用户头像 */
    private String avatar;

    /** 密码 */
    private String password;

    /** 帐号状态（0正常 1停用） */
    @Excel(name = "帐号状态", readConverterExp = "0=正常,1=停用", combo = {"正常", "停用"})
    private String status;

    /** 删除标志（0代表存在 2代表删除） */
    private String delFlag;

    /** 最后登录IP */
    @Excel(name = "最后登录IP", type = Type.EXPORT)
    private String loginIp;

    /** 最后登录时间 */
    @Excel(name = "最后登录时间", width = 30, dateFormat = "yyyy-MM-dd HH:mm:ss", type = Type.EXPORT)
    @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss")
    private Date loginDate;

    /** 部门对象 */
    @Excels({
        @Excel(name = "部门名称", targetAttr = "deptName", type = Type.EXPORT),
        @Excel(name = "部门负责人", targetAttr = "leader", type = Type.EXPORT)
    })
    private SysDept dept;

    /** 角色对象 */
    private List<SysRole> roles;

    /** 角色组 */
    private Long[] roleIds;

    /** 岗位组 */
    private Long[] postIds;

    /** 角色ID */
    private Long roleId;

    @JsonFormat(pattern = "yyyy-MM-dd")
    @Excel(name = "生日", width = 30, dateFormat = "yyyy-MM-dd", cellType = ColumnType.TEXT)
    @ApiModelProperty("生日")
    private LocalDate birthday;

    @JsonFormat(pattern = "yyyy-MM-dd")
    @Excel(name = "入职时间", width = 30, dateFormat = "yyyy-MM-dd", cellType = ColumnType.TEXT)
    @ApiModelProperty("入职时间")
    private LocalDate employDate;

    @ApiModelProperty("微信openId")
    private String wxOpenId;

    @JsonFormat(pattern = "yyyy-MM-dd")
    @Excel(name = "离职日期", width = 30, dateFormat = "yyyy-MM-dd", cellType = ColumnType.TEXT)
    @ApiModelProperty("离职日期")
    private LocalDate resignDate;

    @Excel(name = "身份证正面")
    @ApiModelProperty("身份证正面")
    private String idCardFront;

    @Excel(name = "身份证反面")
    @ApiModelProperty("身份证反面")
    private String idCardBack;

    @Excel(name = "简历")
    @ApiModelProperty("简历")
    private String resume;

    public SysUser(Long userId) {
        this.userId = userId;
    }

    public static SysUser system() {
        SysUser user = new SysUser();
        user.setUserId(0L);
        user.setUserName("系统");
        return user;
    }

    public boolean isAdmin() {
        return isAdmin(this.userId);
    }

    public static boolean isAdmin(Long userId) {
        return userId != null && 1L == userId;
    }
}
