package com.ruoyi.bst.attach.service.impl;

import java.util.Date;
import java.util.List;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import com.ruoyi.bst.attach.domain.Attach;
import com.ruoyi.bst.attach.domain.AttachQuery;
import com.ruoyi.bst.attach.domain.AttachVO;
import com.ruoyi.bst.attach.mapper.AttachMapper;
import com.ruoyi.bst.attach.service.AttachService;
import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.common.utils.collection.CollectionUtils;

/**
 * 资源Service业务层处理
 *
 * @author ruoyi
 * @date 2025-02-12
 */
@Service
public class AttachServiceImpl implements AttachService
{
    @Autowired
    private AttachMapper attachMapper;

    /**
     * 查询资源
     *
     * @param id 资源主键
     * @return 资源
     */
    @Override
    public AttachVO selectAttachById(Long id)
    {
        return attachMapper.selectAttachById(id);
    }

    /**
     * 查询资源列表
     *
     * @param attach 资源
     * @return 资源
     */
    @Override
    public List<AttachVO> selectAttachList(AttachQuery attach)
    {
        return attachMapper.selectAttachList(attach);
    }

    /**
     * 新增资源
     *
     * @param attach 资源
     * @return 结果
     */
    @Override
    public int insertAttach(Attach attach)
    {
        attach.setCreateTime(DateUtils.getNowDate());
        return attachMapper.insertAttach(attach);
    }

    /**
     * 修改资源
     *
     * @param attach 资源
     * @return 结果
     */
    @Override
    public int updateAttach(Attach attach)
    {
        return attachMapper.updateAttach(attach);
    }

    /**
     * 批量插入资源
     *
     * @param poList 资源列表
     * @return 结果
     */
    @Override
    public int batchInsert(List<Attach> poList){
        if (CollectionUtils.isEmptyElement(poList)) {
            return 0;
        }
        Date now = DateUtils.getNowDate();
        for (Attach attach : poList) {
            attach.setCreateTime(now);
        }
        return attachMapper.batchInsert(poList);
    }

    /**
     * 逻辑删除资源
     *
     * @param ids 资源主键
     * @return 结果
     */
    @Override
    public int logicDel(List<Long> ids) {
        if (CollectionUtils.isEmptyElement(ids)) {
            return 0;
        }
        return attachMapper.logicDel(ids);
    }
}
