package com.ruoyi.bst.customer.mapper;

import java.time.LocalDateTime;
import java.util.List;

import org.apache.ibatis.annotations.Param;

import com.ruoyi.bst.customer.domain.Customer;
import com.ruoyi.bst.customer.domain.CustomerQuery;
import com.ruoyi.bst.customer.domain.CustomerVO;
import com.ruoyi.common.vo.LocalDateIntegerVO;
import com.ruoyi.common.vo.StringIntegerVO;

/**
 * 客户Mapper接口
 *
 * @author ruoyi
 * @date 2025-01-22
 */
public interface CustomerMapper
{
    /**
     * 查询客户
     *
     * @param id 客户主键
     * @return 客户
     */
    CustomerVO selectCustomerById(Long id);

    /**
     * 查询客户列表
     *
     * @param query 客户
     * @return 客户集合
     */
    List<CustomerVO> selectCustomerList(@Param("query")CustomerQuery query);

    /**
     * 新增客户
     *
     * @param customer 客户
     * @return 结果
     */
    int insertCustomer(Customer customer);

    /**
     * 修改客户
     *
     * @param customer 客户
     * @return 结果
     */
    public int updateCustomer(@Param("data") Customer customer);

    /**
     * 查询客户数量
     * @param query
     * @return
     */
    int selectCount(@Param("query") CustomerQuery query);

    /**
     * 查询客户数量
     * @param query
     * @return
     */
    List<StringIntegerVO> selectCountGroupByStatus(@Param("query") CustomerQuery query);

    /**
     * 更新客户跟进时间
     */
    int updateFollowTime(@Param("customerId") Long customerId,
                         @Param("lastFollowTime") LocalDateTime lastFollowTime
                         );

    /**
     * 逻辑删除
     * @param ids
     * @return
     */
    int logicDel(@Param("ids") List<Long> ids);

    /**
     * 查询每日创建客户统计
     * @param query
     * @return
     */
    List<LocalDateIntegerVO> selectDailyCreateCount(@Param("query") CustomerQuery query);
}
