package com.ruoyi.bst.customer.service.impl;

import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import com.ruoyi.bst.customer.domain.CustomerQuery;
import com.ruoyi.bst.customer.domain.CustomerVO;
import com.ruoyi.bst.customer.service.CustomerService;
import com.ruoyi.bst.customer.service.CustomerValidator;
import com.ruoyi.common.utils.ServiceUtil;

@Service
public class CustomerValidatorImpl implements CustomerValidator{

    @Autowired
    private CustomerService customerService;

    @Override
    public void validate(CustomerVO vo) {
        ServiceUtil.assertion(vo == null, "客户信息不能为空");

        // 校验客户编号
        ServiceUtil.assertion(!this.isUniqueCode(vo.getId(), vo.getCode()), "客户编号为%s的客户已存在", vo.getCode());
    }

    /**
     * 校验客户编号
     * @param id 客户ID
     * @param code 客户编号
     * @return
     */
    private boolean isUniqueCode(Long id, String code) {
        if (StringUtils.isBlank(code)) {
            return true;
        }
        
        CustomerQuery query = new CustomerQuery();
        query.setEqCode(code);
        query.setExcludeId(id);
        return customerService.selectCount(query) == 0;
    }
    
}
