package com.ruoyi.bst.message.service.impl;

import java.time.LocalDateTime;
import java.util.Date;
import java.util.List;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import com.ruoyi.bst.message.domain.Message;
import com.ruoyi.bst.message.domain.MessageQuery;
import com.ruoyi.bst.message.domain.MessageVO;
import com.ruoyi.bst.message.mapper.MessageMapper;
import com.ruoyi.bst.message.service.MessageService;
import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.common.utils.collection.CollectionUtils;
import com.ruoyi.ws.service.WebSocketService;

import lombok.extern.slf4j.Slf4j;

/**
 * 消息Service业务层处理
 *
 * @author ruoyi
 * @date 2025-02-22
 */
@Service
@Slf4j
public class MessageServiceImpl implements MessageService
{
    @Autowired
    private MessageMapper messageMapper;

    @Autowired
    private WebSocketService webSocketService;

    /**
     * 查询消息
     *
     * @param id 消息主键
     * @return 消息
     */
    @Override
    public MessageVO selectMessageById(Long id)
    {
        return messageMapper.selectMessageById(id);
    }

    /**
     * 查询消息列表
     *
     * @param message 消息
     * @return 消息
     */
    @Override
    public List<MessageVO> selectMessageList(MessageQuery message)
    {
        return messageMapper.selectMessageList(message);
    }

    /**
     * 新增消息
     *
     * @param message 消息
     * @return 结果
     */
    @Override
    public int insertMessage(Message message)
    {
        message.setCreateTime(DateUtils.getNowDate());
        int rows = messageMapper.insertMessage(message);
        if (rows > 0) {
            if (message.getUserId() != null) {
                webSocketService.sendMessageToUser(message, message.getUserId());
            }
        }
        return rows;
    }

    /**
     * 修改消息
     *
     * @param message 消息
     * @return 结果
     */
    @Override
    public int updateMessage(Message message)
    {
        return messageMapper.updateMessage(message);
    }

    /**
     * 批量删除消息
     *
     * @param ids 需要删除的消息主键
     * @return 结果
     */
    @Override
    public int deleteMessageByIds(Long[] ids)
    {
        return messageMapper.deleteMessageByIds(ids);
    }

    /**
     * 删除消息信息
     *
     * @param id 消息主键
     * @return 结果
     */
    @Override
    public int deleteMessageById(Long id)
    {
        return messageMapper.deleteMessageById(id);
    }

    @Override
    public int read(Long userId, Long id){
        // 两个条件不允许同时为空
        if (id == null && userId == null) {
            return 0;
        }
        Message data = new Message();
        data.setIsRead(true);
        data.setReadTime(LocalDateTime.now());
        MessageQuery query = new MessageQuery();
        query.setUserId(userId);
        query.setId(id);
        query.setIsRead(false);
        return messageMapper.updateByQuery(data, query);
    }

    @Override
    public int selectCount(MessageQuery query)
    {
        return messageMapper.selectCount(query);
    }

    @Override
    public int batchInsert(List<Message> list) {
        if (CollectionUtils.isEmptyElement(list)) {
            return 0;
        }
        Date now = DateUtils.getNowDate();
        list.forEach(message -> {
            message.setCreateTime(now);
        });
        int rows = messageMapper.batchInsert(list);

        if (rows > 0) {
            for (Message message : list) {
                try {
                    if (message.getUserId() != null) {
                    webSocketService.sendMessageToUser(message, message.getUserId());
                }
                } catch (Exception e) {
                    log.error("发送消息给用户{}失败", message.getUserId(), e);
                }
            }
        }

        return rows;
    }
}
