package com.ruoyi.bst.projectMember.service;

import java.util.List;

import com.ruoyi.bst.projectMember.domain.ProjectMember;
import com.ruoyi.bst.projectMember.domain.ProjectMemberQuery;
import com.ruoyi.bst.projectMember.domain.ProjectMemberVO;

/**
 * 项目成员Service接口
 *
 * @author ruoyi
 * @date 2025-03-06
 */
public interface ProjectMemberService
{
    /**
     * 查询项目成员
     *
     * @param id 项目成员主键
     * @return 项目成员
     */
    public ProjectMemberVO selectProjectMemberById(Long id);

    /**
     * 查询项目成员列表
     *
     * @param projectMember 项目成员
     * @return 项目成员集合
     */
    public List<ProjectMemberVO> selectProjectMemberList(ProjectMemberQuery projectMember);

    /**
     * 新增项目成员
     *
     * @param projectMember 项目成员
     * @return 结果
     */
    public int insertProjectMember(ProjectMember projectMember);

    /**
     * 修改项目成员
     *
     * @param projectMember 项目成员
     * @return 结果
     */
    public int updateProjectMember(ProjectMember projectMember);

    /**
     * 批量删除项目成员
     *
     * @param ids 需要删除的项目成员主键集合
     * @return 结果
     */
    public int deleteProjectMemberByIds(List<Long> ids);

    /**
     * 查询项目成员列表
     *
     * @param projectId 项目ID
     * @return 项目成员列表
     */
    public List<ProjectMemberVO> selectListByProjectId(Long projectId);

    /**
     * 批量插入项目成员
     *
     * @param addList 新增项目成员列表
     */
    public int batchInsert(List<? extends ProjectMember> list);

    /**
     * 批量更新项目成员
     *
     * @param updateList 更新项目成员列表
     */
    public int batchUpdate(List<? extends ProjectMember> list);

    /**
     * 批量删除项目成员
     *
     * @param delList 删除项目成员列表
     */
    public int batchDelete(List<? extends ProjectMember> list);

    /**
     * 根据项目ID列表查询项目成员列表
     * @param projectIds 项目ID列表
     * @return 项目成员列表
     */
    public List<ProjectMemberVO> selectListByProjectIds(List<Long> projectIds);

    
    
}
