package com.ruoyi.bst.projectMember.service.impl;

import java.time.LocalDateTime;
import java.util.Collections;
import java.util.List;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import com.ruoyi.bst.projectMember.domain.ProjectMember;
import com.ruoyi.bst.projectMember.domain.ProjectMemberQuery;
import com.ruoyi.bst.projectMember.domain.ProjectMemberVO;
import com.ruoyi.bst.projectMember.mapper.ProjectMemberMapper;
import com.ruoyi.bst.projectMember.service.ProjectMemberService;
import com.ruoyi.common.utils.collection.CollectionUtils;

/**
 * 项目成员Service业务层处理
 *
 * @author ruoyi
 * @date 2025-03-06
 */
@Service
public class ProjectMemberServiceImpl implements ProjectMemberService
{
    @Autowired
    private ProjectMemberMapper projectMemberMapper;

    /**
     * 查询项目成员
     *
     * @param id 项目成员主键
     * @return 项目成员
     */
    @Override
    public ProjectMemberVO selectProjectMemberById(Long id)
    {
        return projectMemberMapper.selectProjectMemberById(id);
    }

    /**
     * 查询项目成员列表
     *
     * @param projectMember 项目成员
     * @return 项目成员
     */
    @Override
    public List<ProjectMemberVO> selectProjectMemberList(ProjectMemberQuery projectMember)
    {
        return projectMemberMapper.selectProjectMemberList(projectMember);
    }

    /**
     * 新增项目成员
     *
     * @param projectMember 项目成员
     * @return 结果
     */
    @Override
    public int insertProjectMember(ProjectMember projectMember)
    {
        return projectMemberMapper.insertProjectMember(projectMember);
    }

    /**
     * 修改项目成员
     *
     * @param projectMember 项目成员
     * @return 结果
     */
    @Override
    public int updateProjectMember(ProjectMember projectMember)
    {
        return projectMemberMapper.updateProjectMember(projectMember);
    }

    /**
     * 批量删除项目成员
     *
     * @param ids 需要删除的项目成员主键
     * @return 结果
     */
    @Override
    public int deleteProjectMemberByIds(List<Long> ids)
    {
        return projectMemberMapper.deleteProjectMemberByIds(ids);
    }


    @Override
    public List<ProjectMemberVO> selectListByProjectId(Long projectId) {
        if (projectId == null) {
            return Collections.emptyList();
        }
        ProjectMemberQuery query = new ProjectMemberQuery();
        query.setProjectId(projectId);
        return projectMemberMapper.selectProjectMemberList(query);
    }

    @Override
    public int batchInsert(List<? extends ProjectMember> list) {
        if (CollectionUtils.isEmptyElement(list)) {
            return 0;
        }
        LocalDateTime now = LocalDateTime.now();
        list.forEach(item -> {
            item.setJoinTime(now);
        });
        return projectMemberMapper.batchInsert(list);
    }

    @Override
    public int batchUpdate(List<? extends ProjectMember> list) {
        if (CollectionUtils.isEmptyElement(list)) {
            return 0;
        }
        return projectMemberMapper.batchUpdate(list);
    }

    @Override
    public int batchDelete(List<? extends ProjectMember> list) {
        if (CollectionUtils.isEmptyElement(list)) {
            return 0;
        }
        return this.deleteProjectMemberByIds(CollectionUtils.map(list, ProjectMember::getId));
    }

    @Override
    public List<ProjectMemberVO> selectListByProjectIds(List<Long> projectIds) {
        if (CollectionUtils.isEmptyElement(projectIds)) {
            return Collections.emptyList();
        }
        ProjectMemberQuery query = new ProjectMemberQuery();
        query.setProjectIds(projectIds);
        return projectMemberMapper.selectProjectMemberList(query);
    }
    
    
}
