package com.ruoyi.bst.taskMember.service;

import java.util.List;

import com.ruoyi.bst.taskMember.domain.TaskMember;
import com.ruoyi.bst.taskMember.domain.TaskMemberQuery;
import com.ruoyi.bst.taskMember.domain.TaskMemberVO;

/**
 * 任务成员Service接口
 *
 * @author ruoyi
 * @date 2025-03-06
 */
public interface TaskMemberService
{
    /**
     * 查询任务成员
     *
     * @param id 任务成员主键
     * @return 任务成员
     */
    public TaskMemberVO selectTaskMemberById(Long id);

    /**
     * 查询任务成员列表
     *
     * @param taskMember 任务成员
     * @return 任务成员集合
     */
    public List<TaskMemberVO> selectTaskMemberList(TaskMemberQuery taskMember);

    /**
     * 新增任务成员
     *
     * @param taskMember 任务成员
     * @return 结果
     */
    public int insertTaskMember(TaskMember taskMember);

    /**
     * 修改任务成员
     *
     * @param taskMember 任务成员
     * @return 结果
     */
    public int updateTaskMember(TaskMember taskMember);

    /**
     * 批量删除任务成员
     *
     * @param ids 需要删除的任务成员主键集合
     * @return 结果
     */
    public int deleteTaskMemberByIds(List<Long> ids);


    /**
     * 根据任务ID列表查询成员列表
     * @param taskIds 任务ID列表
     * @return 成员列表
     */
    public List<TaskMemberVO> selectListByTaskIds(List<Long> taskIds);

    /**
     * 根据任务ID查询成员列表
     * @param id 任务ID
     * @return 成员列表
     */
    public List<TaskMemberVO> selectListByTaskId(Long id);

    /**
     * 批量新增任务成员
     * @param addList 新增列表
     * @return 结果
     */
    public int batchInsert(List<? extends TaskMember> list);

    /**
     * 批量更新任务成员
     * @param updateList 更新列表
     * @return 结果
     */
    public int batchUpdate(List<? extends TaskMember> list);

    /**
     * 批量删除任务成员
     * @param list 删除列表
     * @return 结果
     */
    public int batchDelete(List<? extends TaskMember> list);

    /**
     * 接收任务
     * @param taskId 任务ID
     * @param userId 用户ID
     */
    public int receive(Long taskId, Long userId);

    /**
     * 提交任务
     * @param taskId 任务ID
     * @param userId 用户ID
     * @param submitId 提交ID
     */
    public int submit(Long taskId, Long userId, Long submitId);
}
