package com.ruoyi.bst.taskMember.service.impl;

import java.time.LocalDateTime;
import java.util.Collections;
import java.util.List;
import java.util.stream.Collectors;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import com.ruoyi.bst.taskMember.domain.TaskMember;
import com.ruoyi.bst.taskMember.domain.TaskMemberQuery;
import com.ruoyi.bst.taskMember.domain.TaskMemberVO;
import com.ruoyi.bst.taskMember.domain.enums.TaskMemberStatus;
import com.ruoyi.bst.taskMember.mapper.TaskMemberMapper;
import com.ruoyi.bst.taskMember.service.TaskMemberService;
import com.ruoyi.common.utils.collection.CollectionUtils;

/**
 * 任务成员Service业务层处理
 *
 * @author ruoyi
 * @date 2025-03-06
 */
@Service
public class TaskMemberServiceImpl implements TaskMemberService
{
    @Autowired
    private TaskMemberMapper taskMemberMapper;

    /**
     * 查询任务成员
     *
     * @param id 任务成员主键
     * @return 任务成员
     */
    @Override
    public TaskMemberVO selectTaskMemberById(Long id)
    {
        return taskMemberMapper.selectTaskMemberById(id);
    }

    /**
     * 查询任务成员列表
     *
     * @param taskMember 任务成员
     * @return 任务成员
     */
    @Override
    public List<TaskMemberVO> selectTaskMemberList(TaskMemberQuery taskMember)
    {
        return taskMemberMapper.selectTaskMemberList(taskMember);
    }

    /**
     * 新增任务成员
     *
     * @param taskMember 任务成员
     * @return 结果
     */
    @Override
    public int insertTaskMember(TaskMember taskMember)
    {
        return taskMemberMapper.insertTaskMember(taskMember);
    }

    /**
     * 修改任务成员
     *
     * @param taskMember 任务成员
     * @return 结果
     */
    @Override
    public int updateTaskMember(TaskMember taskMember)
    {
        return taskMemberMapper.updateTaskMember(taskMember);
    }

    /**
     * 批量删除任务成员
     *
     * @param ids 需要删除的任务成员主键
     * @return 结果
     */
    @Override
    public int deleteTaskMemberByIds(List<Long> ids)
    {
        return taskMemberMapper.deleteTaskMemberByIds(ids);
    }

    @Override
    public List<TaskMemberVO> selectListByTaskIds(List<Long> taskIds) {
        if (CollectionUtils.isEmptyElement(taskIds)) {
            return Collections.emptyList();
        }

        TaskMemberQuery query = new TaskMemberQuery();
        query.setTaskIds(taskIds);
        return taskMemberMapper.selectTaskMemberList(query);
    }

    @Override
    public List<TaskMemberVO> selectListByTaskId(Long id) {
        if (id == null) {
            return Collections.emptyList();
        }
        TaskMemberQuery query = new TaskMemberQuery();
        query.setTaskId(id);
        return taskMemberMapper.selectTaskMemberList(query);
    }

    @Override
    public int batchInsert(List<? extends TaskMember> list) {
        if (CollectionUtils.isEmptyElement(list)) {
            return 0;
        }
        LocalDateTime now = LocalDateTime.now();
        list.forEach(member -> {
            member.setStatus(TaskMemberStatus.WAIT_RECEIVE.getStatus());
            member.setJoinTime(now);
        });
        return taskMemberMapper.batchInsert(list);
    }

    @Override
    public int batchUpdate(List<? extends TaskMember> list) {
        if (CollectionUtils.isEmptyElement(list)) {
            return 0;
        }
        return taskMemberMapper.batchUpdate(list);
    }

    @Override
    public int batchDelete(List<? extends TaskMember> list) {
        if (CollectionUtils.isEmptyElement(list)) {
            return 0;
        }
        return this.deleteTaskMemberByIds(list.stream().map(TaskMember::getId).collect(Collectors.toList()));
    }

    @Override
    public int receive(Long taskId, Long userId) {
        if (taskId == null || userId == null) {
            return 0;
        }
        TaskMember data = new TaskMember();
        data.setStatus(TaskMemberStatus.PROCESSING.getStatus());
        data.setReceiveTime(LocalDateTime.now());

        TaskMemberQuery query = new TaskMemberQuery();
        query.setTaskId(taskId);
        query.setUserId(userId);
        query.setStatusList(TaskMemberStatus.canReceive());
        return taskMemberMapper.updateByQuery(data, query);
    }

    @Override
    public int submit(Long taskId, Long userId, Long submitId) {
        if (taskId == null || userId == null) {
            return 0;
        }
        TaskMember data = new TaskMember();
        data.setStatus(TaskMemberStatus.SUBMITED.getStatus());
        data.setSubmitId(submitId);

        TaskMemberQuery query = new TaskMemberQuery();
        query.setTaskId(taskId);
        query.setUserId(userId);
        return taskMemberMapper.updateByQuery(data, query);
    }

}
