package com.ruoyi.bst.verify.service.impl;

import java.util.Collections;
import java.util.List;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import com.ruoyi.bst.verify.domain.Verify;
import com.ruoyi.bst.verify.domain.VerifyQuery;
import com.ruoyi.bst.verify.domain.VerifyVO;
import com.ruoyi.bst.verify.domain.enums.VerifyBstType;
import com.ruoyi.bst.verify.mapper.VerifyMapper;
import com.ruoyi.bst.verify.service.VerifyService;
import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.common.utils.collection.CollectionUtils;

/**
 * 审核Service业务层处理
 *
 * @author ruoyi
 * @date 2025-02-08
 */
@Service
public class VerifyServiceImpl implements VerifyService
{
    @Autowired
    private VerifyMapper verifyMapper;

    /**
     * 查询审核
     *
     * @param id 审核主键
     * @return 审核
     */
    @Override
    public VerifyVO selectVerifyById(Long id)
    {
        return verifyMapper.selectVerifyById(id);
    }

    /**
     * 查询审核列表
     *
     * @param verify 审核
     * @return 审核
     */
    @Override
    public List<VerifyVO> selectVerifyList(VerifyQuery verify)
    {
        return verifyMapper.selectVerifyList(verify);
    }

    /**
     * 新增审核
     *
     * @param verify 审核
     * @return 结果
     */
    @Override
    public int insertVerify(Verify verify)
    {
        verify.setCreateTime(DateUtils.getNowDate());
        return verifyMapper.insertVerify(verify);
    }

    /**
     * 修改审核
     *
     * @param verify 审核
     * @return 结果
     */
    @Override
    public int updateVerify(Verify verify)
    {
        return verifyMapper.updateVerify(verify);
    }

    /**
     * 批量删除审核
     *
     * @param ids 需要删除的审核主键
     * @return 结果
     */
    @Override
    public int logicDel(List<Long> ids)
    {
        return verifyMapper.logicDel(ids);
    }

    @Override
    public List<VerifyVO> selectListByBstIds(VerifyBstType bstType, List<Long> bstIds) {
        if (CollectionUtils.isEmptyElement(bstIds)) {
            return Collections.emptyList();
        }
        VerifyQuery query = new VerifyQuery();
        query.setBstType(bstType.getType());
        query.setBstIds(bstIds);
        return verifyMapper.selectVerifyList(query);
    }


}
