package com.ruoyi.dashboard.project.service;

import java.time.LocalDate;
import java.util.ArrayList;
import java.util.List;
import java.util.Objects;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import com.ruoyi.bst.project.domain.ProjectQuery;
import com.ruoyi.bst.project.domain.enums.ProjectStatus;
import com.ruoyi.bst.project.mapper.ProjectMapper;
import com.ruoyi.bst.project.service.ProjectService;
import com.ruoyi.common.utils.bean.BeanUtils;
import com.ruoyi.common.vo.IntegerIntegerVO;
import com.ruoyi.common.vo.StringIntegerVO;
import com.ruoyi.dashboard.index.domain.brief.BriefKeys;
import com.ruoyi.dashboard.index.domain.brief.ProjectBriefVO;
import com.ruoyi.dashboard.project.domain.monthProject.MonthProjectQuery;
import com.ruoyi.dashboard.project.domain.monthProject.MonthProjectVO;

@Service
public class DashboardProjectService {

    @Autowired
    private ProjectService projectService;

    @Autowired
    private ProjectMapper projectMapper;

    public List<MonthProjectVO> selectMonthProject(MonthProjectQuery query) {
        List<MonthProjectVO> result = new ArrayList<>();

        // 查询每月新增的项目数
        List<IntegerIntegerVO> startList = this.selectCountGroupByStartMonth(query.toProjectQueryByStart());

        // 查询每月完成的项目数
        List<IntegerIntegerVO> finishList = this.selectCountGroupByCompleteMonth(query.toProjectQueryByComplete());

        // 构造成12月的数据
        for (int i = 1; i <= 12; i ++) {
            MonthProjectVO vo = new MonthProjectVO();
            vo.setYear(query.getYear());
            vo.setMonth(i);

            // 开始项目
            IntegerIntegerVO startCount = startList.stream().filter(item -> Objects.equals(vo.getMonth(), item.getKey())).findFirst().orElse(null);
            if (startCount == null || startCount.getValue() == null) {
                vo.setStartCount(0);
            } else {
                vo.setStartCount(startCount.getValue());
            }

            // 完成项目
            IntegerIntegerVO finishCount = finishList.stream().filter(item -> Objects.equals(vo.getMonth(), item.getKey())).findFirst().orElse(null);
            if (finishCount == null || finishCount.getValue() == null) {
                vo.setFinishCount(0);
            } else {
                vo.setFinishCount(finishCount.getValue());
            }

            result.add(vo);
        }

        return result;
    }

    // 查询项目概览
    public ProjectBriefVO selectProjectBrief(ProjectQuery query, List<String> keyList) {

        ProjectBriefVO vo = new ProjectBriefVO();

        if (keyList != null) {
            if (keyList.contains(BriefKeys.PROJECT_STATUS)) {
                List<StringIntegerVO> projectMap = projectService.selectCountGroupByStatus(query);
                vo.setStatusGroup(projectMap);
            }
            if (keyList.contains(BriefKeys.PROJECT_DEV_ON_TIME_COMPLETED)) {
                vo.setDevOnTimeCompleted(this.selectDevOnTimeCompletedCount(query));
            }
            if (keyList.contains(BriefKeys.PROJECT_DEV_COMPLETED)) {
                vo.setDevCompleted(this.selectDevCompletedCount(query));
            }
            if (keyList.contains(BriefKeys.PROJECT_OVERDUE_DEV_UNCOMPLETED)) {
                vo.setDevOverdueUncompleted(this.selectDevOverdueUncompletedCount(query));
            }
            if (keyList.contains(BriefKeys.PROJECT_OVERDUE_DEV_COMPLETED)) {
                vo.setDevOverdueCompleted(this.selectDevOverdueCompletedCount(query));
            }
            if (keyList.contains(BriefKeys.PROJECT_DEV_OVERDUE)) {
                vo.setDevOverdue(this.selectDevOverdueCount(query));
            }
            if (keyList.contains(BriefKeys.PROJECT_DEV_SOON_EXPIRE)) {
                vo.setDevSoonExpire(this.selectDevSoonExpireCount(query));
            }
        }

        return vo;
    }

    //【通用】查询项目数量
    public int selectCount(ProjectQuery query) {
        return projectMapper.selectCount(query);
    }

    //【通用】按完成月查询完成项目数
    public List<IntegerIntegerVO> selectCountGroupByCompleteMonth(ProjectQuery query) {
        return projectMapper.selectCountGroupByCompleteMonth(query);
    }

    //【通用】按开始月查询开始项目数
    public List<IntegerIntegerVO> selectCountGroupByStartMonth(ProjectQuery query) {
        return projectMapper.selectCountGroupByStartMonth(query);
    }

    // 查询开发即将到期项目数
    private int selectDevSoonExpireCount(ProjectQuery projectQuery) {
        ProjectQuery query = new ProjectQuery();
        BeanUtils.copyBeanProp(query, projectQuery);
        query.setStatusList(ProjectStatus.devUnCompleted());
        query.setExpectedCompleteDateEnd(LocalDate.now().plusDays(2));    // 剩余2天，即视为即将到期
        return this.selectCount(query);
    }

    // 查询开发逾期项目数
    private int selectDevOverdueCount(ProjectQuery projectQuery) {
        ProjectQuery query = new ProjectQuery();
        BeanUtils.copyBeanProp(query, projectQuery);
        query.setDevOverdue(true);
        return this.selectCount(query);
    }
    

    // 查询完成数
    private int selectDevCompletedCount(ProjectQuery projectQuery) {
        ProjectQuery query = new ProjectQuery();
        BeanUtils.copyBeanProp(query, projectQuery);
        query.setStatusList(ProjectStatus.completedList());
        return this.selectCount(query);
    }

    // 查询正常开发完成数
    private int selectDevOnTimeCompletedCount(ProjectQuery projectQuery) {
        ProjectQuery query = new ProjectQuery();
        BeanUtils.copyBeanProp(query, projectQuery);
        query.setStatusList(ProjectStatus.completedList());
        query.setDevOverdue(false);
        return this.selectCount(query);
    }

    // 开发逾期未完成
    private int selectDevOverdueUncompletedCount(ProjectQuery projectQuery) {
        ProjectQuery query = new ProjectQuery();
        BeanUtils.copyBeanProp(query, projectQuery);
        query.setDevOverdue(true);
        query.setStatusList(ProjectStatus.devUnCompleted());
        return this.selectCount(query);
    }

    // 开发逾期完成
    private int selectDevOverdueCompletedCount(ProjectQuery projectQuery) {
        ProjectQuery query = new ProjectQuery();
        BeanUtils.copyBeanProp(query, projectQuery);
        query.setDevOverdue(true);
        query.setStatusList(ProjectStatus.completedList());
        return this.selectCount(query);
    }

}
