package com.ruoyi.dashboard.task.service;

import java.time.LocalDate;
import java.time.LocalDateTime;
import java.util.List;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import com.ruoyi.bst.task.domain.TaskQuery;
import com.ruoyi.bst.task.domain.enums.TaskStatus;
import com.ruoyi.bst.task.service.TaskService;
import com.ruoyi.common.utils.bean.BeanUtils;
import com.ruoyi.common.vo.StringIntegerVO;
import com.ruoyi.dashboard.index.domain.brief.BriefKeys;
import com.ruoyi.dashboard.index.domain.brief.TaskBriefVO;
@Service
public class DashboardTaskService {

    @Autowired
    private TaskService taskService;

    public TaskBriefVO selectTaskBrief(TaskQuery query, List<String> keyList) {
        TaskBriefVO vo = new TaskBriefVO();
        if (keyList != null) {
            if (keyList.contains(BriefKeys.TASK_STATUS)) {
                List<StringIntegerVO> statusMap = taskService.selectCountGroupByStatus(query);
                vo.setStatusGroup(statusMap);
            }
            if (keyList.contains(BriefKeys.TASK_TYPE)) {
                List<StringIntegerVO> typeMap = taskService.selectCountGroupByType(query);
                vo.setTypeGroup(typeMap);
            }
            if (keyList.contains(BriefKeys.TASK_OVERDUE_UNCOMPLETED)) {
                vo.setOverdueUncompleted(this.selectCountOverdueUncompleted(query));
            }
            if (keyList.contains(BriefKeys.TASK_OVERDUE_COMPLETED)) {
                vo.setOverdueCompleted(this.selectCountOverdueCompleted(query));
            }
            if (keyList.contains(BriefKeys.TASK_TODAY_COMPLETED)) {
                vo.setTodayCompleted(this.selectCountTodayCompleted(query));
            }
            if (keyList.contains(BriefKeys.TASK_SOON_EXPIRE)) {
                vo.setSoonExpire(this.selectCountSoonExpire(query));
            }
        }

        return vo;
    }

    /**
     * 查询即将过期的任务数
     * @param taskQuery
     * @return
     */
    private int selectCountSoonExpire(TaskQuery taskQuery) {
        TaskQuery query = new TaskQuery ();
        BeanUtils.copyBeanProp(query, taskQuery);
        query.setStatusList(TaskStatus.unComplete());
        query.setExpireTimeEnd(LocalDateTime.now().plusDays(2));  // 查询剩余过期时间小于48小时，且未完成的任务
        return taskService.selectCount(query);
    }

    /**
     * 查询今日完成任务数
     * @param taskQuery
     * @return
     */
    private int selectCountTodayCompleted(TaskQuery taskQuery) {
        TaskQuery query = new TaskQuery();
        BeanUtils.copyBeanProp(query, taskQuery);
        query.setStatusList(TaskStatus.complete());
        query.setPassDate(LocalDate.now());
        return taskService.selectCount(query);
    }

    /**
     * 查询逾期未完成任务数
     * @param taskQuery
     * @return
     */
    private int selectCountOverdueUncompleted(TaskQuery taskQuery) {
        TaskQuery query = new TaskQuery();
        BeanUtils.copyBeanProp(query, taskQuery);
        query.setStatusList(TaskStatus.unComplete());
        query.setOverdue(true);
        return taskService.selectCount(query);
    }

    /**
     * 查询逾期完成任务数
     * @param taskQuery
     * @return
     */
    private int selectCountOverdueCompleted(TaskQuery taskQuery) {
        TaskQuery query = new TaskQuery();
        BeanUtils.copyBeanProp(query, taskQuery);
        query.setStatusList(TaskStatus.complete());
        query.setOverdue(true);
        return taskService.selectCount(query);
    }
}
