package com.ruoyi.web.bst;

import java.util.List;

import javax.servlet.http.HttpServletResponse;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import com.ruoyi.bst.attachClassify.domain.AttachClassify;
import com.ruoyi.bst.attachClassify.domain.AttachClassifyQuery;
import com.ruoyi.bst.attachClassify.domain.AttachClassifyVO;
import com.ruoyi.bst.attachClassify.service.AttachClassifyService;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.core.page.TableDataInfo;
import com.ruoyi.common.core.validate.ValidGroup;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.common.utils.poi.ExcelUtil;

/**
 * 资源分类Controller
 *
 * @author ruoyi
 * @date 2025-02-12
 */
@RestController
@RequestMapping("/bst/attachClassify")
public class AttachClassifyController extends BaseController
{
    @Autowired
    private AttachClassifyService attachClassifyService;

    /**
     * 查询资源分类列表
     */
    @PreAuthorize("@ss.hasPermi('bst:attachClassify:list')")
    @GetMapping("/list")
    public TableDataInfo list(AttachClassifyQuery query)
    {
        startPage();
        startOrderBy();
        List<AttachClassifyVO> list = attachClassifyService.selectAttachClassifyList(query);
        return getDataTable(list);
    }

    /**
     * 查询全部资源分类
     */
    @GetMapping("/listAll")
    public AjaxResult listAll(){
        return success(attachClassifyService.selectAllNameList());
    }

    /**
     * 导出资源分类列表
     */
    @PreAuthorize("@ss.hasPermi('bst:attachClassify:export')")
    @Log(title = "资源分类", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, AttachClassifyQuery query)
    {
        List<AttachClassifyVO> list = attachClassifyService.selectAttachClassifyList(query);
        ExcelUtil<AttachClassifyVO> util = new ExcelUtil<AttachClassifyVO>(AttachClassifyVO.class);
        util.exportExcel(response, list, "资源分类数据");
    }

    /**
     * 获取资源分类详细信息
     */
    @PreAuthorize("@ss.hasPermi('bst:attachClassify:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(attachClassifyService.selectAttachClassifyById(id));
    }

    /**
     * 新增资源分类
     */
    @PreAuthorize("@ss.hasPermi('bst:attachClassify:add')")
    @Log(title = "资源分类", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody @Validated(ValidGroup.Create.class) AttachClassify attachClassify)
    {
        attachClassify.setCreateId(getUserId());
        return toAjax(attachClassifyService.insertAttachClassify(attachClassify));
    }

    /**
     * 修改资源分类
     */
    @PreAuthorize("@ss.hasPermi('bst:attachClassify:edit')")
    @Log(title = "资源分类", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody @Validated(ValidGroup.Update.class) AttachClassify attachClassify)
    {
        return toAjax(attachClassifyService.updateAttachClassify(attachClassify));
    }

    /**
     * 删除资源分类
     */
    @PreAuthorize("@ss.hasPermi('bst:attachClassify:remove')")
    @Log(title = "资源分类", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable List<Long> ids)
    {
        return toAjax(attachClassifyService.logicDel(ids));
    }
}
