package com.ruoyi.web.bst;

import java.util.List;

import javax.servlet.http.HttpServletResponse;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import com.ruoyi.bst.taskMember.domain.TaskMemberQuery;
import com.ruoyi.bst.taskMember.domain.TaskMemberVO;
import com.ruoyi.bst.taskMember.service.TaskMemberService;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.core.page.TableDataInfo;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.common.utils.poi.ExcelUtil;

/**
 * 任务成员Controller
 *
 * @author ruoyi
 * @date 2025-03-06
 */
@RestController
@RequestMapping("/bst/taskMember")
public class TaskMemberController extends BaseController
{
    @Autowired
    private TaskMemberService taskMemberService;

    /**
     * 查询任务成员列表
     */
    @PreAuthorize("@ss.hasPermi('bst:taskMember:list')")
    @GetMapping("/list")
    public TableDataInfo list(TaskMemberQuery query)
    {
        startPage();
        startOrderBy();
        List<TaskMemberVO> list = taskMemberService.selectTaskMemberList(query);
        return getDataTable(list);
    }

    /**
     * 导出任务成员列表
     */
    @PreAuthorize("@ss.hasPermi('bst:taskMember:export')")
    @Log(title = "任务成员", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, TaskMemberQuery query)
    {
        List<TaskMemberVO> list = taskMemberService.selectTaskMemberList(query);
        ExcelUtil<TaskMemberVO> util = new ExcelUtil<TaskMemberVO>(TaskMemberVO.class);
        util.exportExcel(response, list, "任务成员数据");
    }

    /**
     * 获取任务成员详细信息
     */
    @PreAuthorize("@ss.hasPermi('bst:taskMember:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(taskMemberService.selectTaskMemberById(id));
    }

    /**
     * 新增任务成员
     */
    // @PreAuthorize("@ss.hasPermi('bst:taskMember:add')")
    // @Log(title = "任务成员", businessType = BusinessType.INSERT)
    // @PostMapping
    // public AjaxResult add(@RequestBody TaskMember taskMember)
    // {
    //     return toAjax(taskMemberService.insertTaskMember(taskMember));
    // }

    // /**
    //  * 修改任务成员
    //  */
    // @PreAuthorize("@ss.hasPermi('bst:taskMember:edit')")
    // @Log(title = "任务成员", businessType = BusinessType.UPDATE)
    // @PutMapping
    // public AjaxResult edit(@RequestBody TaskMember taskMember)
    // {
    //     return toAjax(taskMemberService.updateTaskMember(taskMember));
    // }

    // /**
    //  * 删除任务成员
    //  */
    // @PreAuthorize("@ss.hasPermi('bst:taskMember:remove')")
    // @Log(title = "任务成员", businessType = BusinessType.DELETE)
	// @DeleteMapping("/{ids}")
    // public AjaxResult remove(@PathVariable Long[] ids)
    // {
    //     return toAjax(taskMemberService.deleteTaskMemberByIds(ids));
    // }
}
