package com.ruoyi.web.bst;

import java.util.List;

import javax.servlet.http.HttpServletResponse;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import com.ruoyi.bst.verify.domain.VerifyQuery;
import com.ruoyi.bst.verify.domain.VerifyVO;
import com.ruoyi.bst.verify.service.VerifyService;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.core.page.TableDataInfo;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.common.utils.poi.ExcelUtil;

/**
 * 审核Controller
 *
 * @author ruoyi
 * @date 2025-02-08
 */
@RestController
@RequestMapping("/bst/verify")
public class VerifyController extends BaseController
{
    @Autowired
    private VerifyService verifyService;

    /**
     * 查询审核列表
     */
    @PreAuthorize("@ss.hasPermi('bst:verify:list')")
    @GetMapping("/list")
    public TableDataInfo list(VerifyQuery query)
    {
        startPage();
        startOrderBy();
        List<VerifyVO> list = verifyService.selectVerifyList(query);
        return getDataTable(list);
    }

    /**
     * 导出审核列表
     */
    @PreAuthorize("@ss.hasPermi('bst:verify:export')")
    @Log(title = "审核", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, VerifyQuery query)
    {
        List<VerifyVO> list = verifyService.selectVerifyList(query);
        ExcelUtil<VerifyVO> util = new ExcelUtil<VerifyVO>(VerifyVO.class);
        util.exportExcel(response, list, "审核数据");
    }

    /**
     * 获取审核详细信息
     */
    @PreAuthorize("@ss.hasPermi('bst:verify:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(verifyService.selectVerifyById(id));
    }

    /**
     * 新增审核
     */
    // @PreAuthorize("@ss.hasPermi('bst:verify:add')")
    // @Log(title = "审核", businessType = BusinessType.INSERT)
    // @PostMapping
    // public AjaxResult add(@RequestBody Verify verify)
    // {
    //     return toAjax(verifyService.insertVerify(verify));
    // }

    // /**
    //  * 修改审核
    //  */
    // @PreAuthorize("@ss.hasPermi('bst:verify:edit')")
    // @Log(title = "审核", businessType = BusinessType.UPDATE)
    // @PutMapping
    // public AjaxResult edit(@RequestBody Verify verify)
    // {
    //     return toAjax(verifyService.updateVerify(verify));
    // }

    // /**
    //  * 删除审核
    //  */
    // @PreAuthorize("@ss.hasPermi('bst:verify:remove')")
    // @Log(title = "审核", businessType = BusinessType.DELETE)
	// @DeleteMapping("/{ids}")
    // public AjaxResult remove(@PathVariable List<Long> ids)
    // {
    //     return toAjax(verifyService.logicDel(ids));
    // }
}
